@@ -25,6 +25,9 @@
 
 #include "autosave.h"
 
+namespace OpenOrienteering {
+
+
 /**
  * @brief AutosavePrivate is a helper class of Autosave.
  * 
@@ -40,7 +43,7 @@ Q_OBJECT
 public:	
 	AutosavePrivate(Autosave& document);
 	
-	virtual ~AutosavePrivate();
+	~AutosavePrivate() override;
 	
 	bool autosaveNeeded();
 	
@@ -60,4 +63,7 @@ private:
 	int  autosave_interval;
 };
 
+
+}  // namespace OpenOrienteering
+
 #endif
