@@ -1,5 +1,5 @@
 /*
- *    Copyright 2016-2017 Kai Pastor
+ *    Copyright 2016-2018 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -37,6 +37,7 @@
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
+#include "settings.h"
 #include "core/georeferencing.h"
 #include "core/latlon.h"
 #include "core/map.h"
@@ -113,7 +114,8 @@ const std::vector<QByteArray>& OgrTemplate::supportedExtensions()
 OgrTemplate::OgrTemplate(const QString& path, Map* map)
 : TemplateMap(path, map)
 {
-	// nothing else
+	connect(&Settings::getInstance(), &Settings::settingsChanged, this, &OgrTemplate::applySettings);
+	
 	const Georeferencing& georef = map->getGeoreferencing();
 	connect(&georef, &Georeferencing::projectionChanged, this, &OgrTemplate::mapTransformationChanged);
 	connect(&georef, &Georeferencing::transformationChanged, this, &OgrTemplate::mapTransformationChanged);
@@ -262,6 +264,9 @@ try
 	auto unit_type = use_real_coords ? OgrFileImport::UnitOnGround : OgrFileImport::UnitOnPaper;
 	OgrFileImport importer{ &file, new_template_map.get(), nullptr, unit_type };
 	
+	// Configure generation of renderables.
+	updateView(*new_template_map);
+	
 	const auto& map_georef = map->getGeoreferencing();
 	
 	if (template_track_compatibility)
@@ -453,6 +458,39 @@ void OgrTemplate::reload()
 
 
 
+void OgrTemplate::applySettings()
+{
+	if (auto* template_map = templateMap())
+		updateView(*template_map);
+}
+
+void OgrTemplate::updateView(Map& template_map)
+{
+	GdalManager manager;
+	const auto enable_hatching = manager.isAreaHatchingEnabled();
+	const auto enable_baseline = manager.isBaselineViewEnabled();
+	
+	bool dirty = false;
+	if (template_map.isAreaHatchingEnabled() != enable_hatching)
+	{
+		template_map.setAreaHatchingEnabled(enable_hatching);
+		dirty = true;
+	}
+	if (template_map.isBaselineViewEnabled() != enable_baseline)
+	{
+		template_map.setBaselineViewEnabled(enable_baseline);
+		dirty = true;
+	}
+	
+	if (dirty && templateMap() == &template_map)
+	{
+		template_map.updateAllObjects();
+		setTemplateAreaDirty();
+	}
+}
+
+
+
 OgrTemplate* OgrTemplate::duplicateImpl() const
 {
 	auto copy = new OgrTemplate(template_path, map);
