@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013 Jan Dalheimer
- *    Copyright 2012-2016  Kai Pastor
+ *    Copyright 2012-2017  Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -20,31 +20,40 @@
 
 #include "settings_dialog.h"
 
-#include <QAbstractButton>
+#include <Qt>
+#include <QtGlobal>
+#include <QAbstractButton> // IWYU pragma: keep
 #include <QAction>
 #include <QDialogButtonBox>
 #include <QFormLayout>
+#include <QFlags>
+#include <QFrame>
 #include <QKeyEvent>
 #include <QLabel>
+#include <QLatin1String>
+#include <QLayout>
 #include <QScrollArea>
 #include <QScroller>
 #include <QStackedWidget>
 #include <QTabWidget>
-#include <QTabBar>
 #include <QToolBar>
 #include <QVBoxLayout>
+#include <QWidget>
 
-#include "util/util.h"
-#include "../util/backports.h"
+#include "gui/main_window.h"
+#include "gui/util_gui.h"
+#include "gui/widgets/editor_settings_page.h"
+#include "gui/widgets/general_settings_page.h"
+#include "gui/widgets/settings_page.h"
+#include "util/backports.h" // IWYU pragma: keep
 
-#include "main_window.h"
-#include "widgets/editor_settings_page.h"
-#include "widgets/general_settings_page.h"
 #ifdef MAPPER_USE_GDAL
-#  include "../gdal/gdal_settings_page.h"
+#  include "gdal/gdal_settings_page.h"
 #endif
 
 
+namespace OpenOrienteering {
+
 SettingsDialog::SettingsDialog(QWidget* parent)
  : QDialog        { parent }
  , tab_widget     { nullptr }
@@ -52,7 +61,7 @@ SettingsDialog::SettingsDialog(QWidget* parent)
 {
 	setWindowTitle(tr("Settings"));
 	
-	QVBoxLayout* layout = new QVBoxLayout(this);
+	auto layout = new QVBoxLayout(this);
 	
 	auto buttons = QDialogButtonBox::StandardButtons{ QDialogButtonBox::Ok };
 	if (MainWindow::mobileMode())
@@ -73,7 +82,7 @@ SettingsDialog::SettingsDialog(QWidget* parent)
 		buttons |=  QDialogButtonBox::Reset | QDialogButtonBox::Cancel | QDialogButtonBox::Help;
 		
 		tab_widget = new QTabWidget();
-#ifndef Q_OS_OSX
+#ifndef Q_OS_MACOS
 		tab_widget->setDocumentMode(true);
 #endif
 		layout->addWidget(tab_widget, 1);
@@ -88,7 +97,7 @@ SettingsDialog::SettingsDialog(QWidget* parent)
 		layout->setContentsMargins(0, 0, 0, 0);
 		layout->setSpacing(0);
 		
-		QVBoxLayout* l = new QVBoxLayout();
+		auto l = new QVBoxLayout();
 		l->setContentsMargins(left, top, right, bottom);
 		l->addWidget(button_box);
 		layout->addLayout(l);
@@ -101,16 +110,15 @@ SettingsDialog::SettingsDialog(QWidget* parent)
 	addPages();
 }
 
-SettingsDialog::~SettingsDialog()
-{
-	// Nothing, not inlined.
-}
+SettingsDialog::~SettingsDialog() = default;
 
-void SettingsDialog::closeEvent(QCloseEvent* e)
+
+
+void SettingsDialog::closeEvent(QCloseEvent* event)
 {
 	if (MainWindow::mobileMode())
 		callOnAllPages(&SettingsPage::apply);
-	QDialog::closeEvent(e);
+	QDialog::closeEvent(event);
 }
 
 void SettingsDialog::keyPressEvent(QKeyEvent* event)
@@ -163,7 +171,7 @@ void SettingsDialog::addPage(SettingsPage* page)
 		
 		auto menu_widget = qobject_cast<QToolBar*>(stack_widget->widget(0));
 		auto action = menu_widget->addAction(page->title());
-		connect(action, &QAction::triggered, [this, scrollarea]()
+		connect(action, &QAction::triggered, this, [this, scrollarea]()
 		{
 			stack_widget->setCurrentWidget(scrollarea);
 			scrollarea->ensureVisible(0, 0);
@@ -218,3 +226,6 @@ void SettingsDialog::buttonPressed(QAbstractButton* button)
 		qDebug("%s: Unexpected button '0x%x'", Q_FUNC_INFO, id);
 	}
 }
+
+
+}  // namespace OpenOrienteering
