@@ -79,6 +79,8 @@ UndoStep* UndoStep::getUndoStepForType(Type type, Map* map)
 		
 	default:
 		qWarning("Undefined undo step type");
+		// fall through
+	case SwitchPartUndoStepTypeV0:
 		return new NoOpUndoStep(map, false);
 	}
 }
