@@ -19,7 +19,13 @@
 
 #include "autosave_t.h"
 
-#include "../src/settings.h"
+#include <QtGlobal>
+#include <QtTest>
+#include <QCoreApplication>
+#include <QString>
+#include <QThread>
+
+#include "settings.h"
 
 
 namespace {
@@ -243,12 +249,11 @@ void AutosaveTest::autosaveStopTest()
 }
 
 /*
- * We select a non-standard QPA because we don't need a real GUI window.
- * 
- * Normally, the "offscreen" plugin would be the correct one.
- * However, it bails out with a QFontDatabase error (cf. QTBUG-33674)
+ * We don't need a real GUI window.
  */
-static auto qpa_selected = qputenv("QT_QPA_PLATFORM", "minimal");
+namespace {
+	auto qpa_selected = qputenv("QT_QPA_PLATFORM", "minimal");  // clazy:exclude=non-pod-global-static
+}
 
 
 QTEST_MAIN(AutosaveTest)
