@@ -1,5 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
+ *    Copyright 2017 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -17,10 +18,10 @@
  *    along with OpenOrienteering.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _OPENORIENTEERING_MAP_EDITOR_T_H
-#define _OPENORIENTEERING_MAP_EDITOR_T_H
+#ifndef OPENORIENTEERING_TOOLS_T_H
+#define OPENORIENTEERING_TOOLS_T_H
 
-#include <QtTest/QtTest>
+#include <QObject>
 
 
 /**
